'use strict';

exports.__esModule = true;

var _child_process = require('child_process');

var _child_process2 = _interopRequireDefault(_child_process);

var _toolConfig = require('@skpm/internal-utils/tool-config');

var _exec = require('@skpm/internal-utils/exec');

var _asyncCommand = require('../utils/async-command');

var _asyncCommand2 = _interopRequireDefault(_asyncCommand);

var _utils = require('../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const config = (0, _toolConfig.get)();

exports.default = (0, _asyncCommand2.default)({
  command: 'log',

  desc: 'Show the Sketch plugins logs.',

  builder: {
    f: {
      description: 'The `-f` option causes tail to not stop when end of file is reached, but rather to wait for additional data to be appended to the input.',
      type: 'boolean',
      alias: 'F',
      default: 'false'
    },
    number: {
      description: 'Shows `number` lines of the logs.',
      type: 'number',
      alias: 'n'
    }
  },

  handler(argv, done) {
    const args = [];

    if (argv.f) {
      args.push('-F');
    } else if (argv.number !== undefined) {
      args.push(`-n ${argv.number}`);
    }

    args.push(config.logsLocation);

    let restarted = false;

    const child = _child_process2.default.spawn('tail', args, {
      cwd: process.cwd()
    });

    if (child.stdout) {
      child.stdout.on('data', data => {
        console.log(String(data).replace(/ «Plugin Output»/g, '').replace(/\n$/g, ''));
      });
    }

    if (child.stderr) {
      child.stderr.on('data', data => {
        const dataString = String(data);
        if (dataString.indexOf('No such file or directory')) {
          restarted = true;
          return (0, _exec.exec)(`touch "${config.logsLocation}"`).then(() => {
            this.handler(argv, done);
          }).catch(err => {
            (0, _utils.error)('while reading the logs');
            done(err);
          });
        }
        return console.error(String(data));
      });
    }

    child.on('exit', () => {
      if (!restarted) {
        done();
      }
    });

    child.on('error', err => {
      (0, _utils.error)('while reading the logs');
      done(err);
    });
  }
});